@@ -17,7 +17,10 @@ def sampleDataSourceMeta(stub, ds_id):
 
 
 def dataSourceUniques(stub):
-    request = api.DataSourceUniquesRequest(dataSourceId=ds_id, columns=['trans', 'symbol', 'currency'])
+    project_cols = ['trans', 'symbol', 'currency']
+    column_types = ["String", "String", "String"]
+    pc = list(map(lambda c: api.ProjectColumn(name=c[0], type=api.ColumnType.Value(c[1])), zip(project_cols, column_types)))
+    request = api.DataSourceUniquesRequest(dataSourceId=ds_id, projectColumns=pc)
     res = stub.dataSourceUniques(request=request)
     for batch in res:
         print(batch)
@@ -33,7 +36,7 @@ def dataSourceQuery(stub):
         },
         {
             "col": "symbol",
-            "filter": list(map(lambda f: api.OptionalString(value=proto.StringValue(value=str(f))), ["RHAT"]))
+            "filter": list(map(lambda f: api.OptionalString(value=proto.StringValue(value=str(f))), ["MSFT"]))
         },
         {
             "col": "currency", "type": "String",
@@ -42,7 +45,7 @@ def dataSourceQuery(stub):
     ]
     pc = list(map(lambda c: api.ProjectColumn(name=c[0], type=api.ColumnType.Value(c[1])), zip(project_cols, column_types)))
     l1fs = list(map(lambda c: api.QueryFilter(stringFilter=api.StringFilter(name=c['col'], stringFilter=c['filter'])), l1_filters))
-    l1q = api.LineQuery(filters=l1fs)
+    l1q = api.LineQuery(filters=l1fs, dataSourceId=ds_id)
     request = api.DataSourceQueryRequest(
         projectColumns=pc,
         lineQueries=[l1q]
@@ -52,7 +55,6 @@ def dataSourceQuery(stub):
         print(batch)
 
 
-
 def run_main():
     ## Setup channel
     channel = grpc.insecure_channel('localhost:50051')
@@ -60,13 +62,13 @@ def run_main():
 
     # List datasources request
     listRequest(rpc_stub)
-
-    # Sample datasource meta request
+    #
+    # # Sample datasource meta request
     sampleDataSourceMeta(rpc_stub, ds_id=ds_id)
-    # try:
-    #     sampleDataSourceMeta(rpc_stub, ds_id=f'garbage id must fail')
-    # except grpc._channel._InactiveRpcError as rpcErr:
-    #     print(f"Got error {rpcErr}")
+    try:
+        sampleDataSourceMeta(rpc_stub, ds_id=f'garbage id must fail')
+    except grpc._channel._InactiveRpcError as rpcErr:
+        print(f"Got error {rpcErr}")
 
     ## datasource uniques
     dataSourceUniques(rpc_stub)
